# -*- coding: utf8 -*-

import re

from django import forms

from bbcode.forms import BBCodeModelForm

from .models import PageWeb


class PageWebForm(BBCodeModelForm):
    def __init__(self, adresse_init, *args, **kwargs):
        super(PageWebForm, self).__init__(*args, **kwargs)

        if adresse_init:
            self.fields["adresse"].initial = adresse_init

    def clean_adresse(self):
        adresse = self.cleaned_data["adresse"]
        if not re.match(r"^[a-z0-9_/-]+$", adresse):
            raise forms.ValidationError("L’adresse ne peut contenir que les caractères suivants : a-z, 0-9, _, - et /.")

        return adresse.lstrip("/")

    class Meta:
        model = PageWeb
        fields = ("titre", "adresse", "contenu")
        bbcode_field = "contenu"
        widgets = {
            "titre": forms.TextInput(attrs={"size": "32"}),
            "adresse": forms.TextInput(attrs={"size": "64"}),
        }
